** How Large Are the Economic Dividends from Closing Gender Employment Gaps in the Middle East and North Africa? by  Fiuratti, Pennings and Torres 2024**
*Figure1.do is a Stata Do File that generates figure 1 of the paper.

use "${path}/RawData/WDI_ready", clear

keep if seriescode == "SL.TLF.CACT.FE.NE.ZS" | seriescode == "SL.TLF.CACT.MA.NE.ZS" | seriescode == "NY.GDP.PCAP.PP.KD"

gen series = 1 if seriescode == "NY.GDP.PCAP.PP.KD" // constant -- GDP per capita, PPP (constant 2017 international $)
replace series = 2 if seriescode == "SL.TLF.CACT.FE.NE.ZS" // Labor force participation rate, female (% of female population ages 15+) (national estimate)
replace series = 3 if seriescode == "SL.TLF.CACT.MA.NE.ZS"

drop seriesname seriescode
drop if series == .

reshape wide value, i(iso year) j(series)
rename value1 gdp_capita
rename value2 flfp
rename value3 mlfp

reshape wide gdp_capita flfp mlfp, i(iso) j(year)

egen last = rowlast(mlfp2009 mlfp2010 mlfp2011 mlfp2012 mlfp2013 mlfp2014 mlfp2015 mlfp2016 mlfp2017 mlfp2018 mlfp2019) // latest data point available
replace mlfp2019 = last if mlfp2019 == . // 24 countries
drop last

reshape long

gen gap = mlfp - flfp

encode iso, gen(iso_num)

gen log_gdp = ln(gdp_capita)

xtset iso_num year

*Figure 1 graph

*ssc install schemepack, replace // if not installed enable this command to install a package that enables running the following command which sets a specific scheme for the graph

set scheme tab2

twoway (scatter gap log_gdp if year == 2019 & region != "MNA") (scatter gap log_gdp if year == 2019 & region == "MNA", mlabel(iso)) if gap >= 0, xlabel(7.3 "$1,500" 8.5 "$5,000" 9.6 "$15,000" 10.3 "$30,000" 11.3 "$80,000") xtitle("GDP per capita (PPP, constant 2017 international $)") ytitle("Gender gap in labor force participation" "(15+, national estimates)") legend(off) graphregion(color(white)) bgcolor(white)
graph export "$path/Figures/Figure1.pdf", replace as(pdf)
