** How Large Are the Economic Dividends from Closing Gender Employment Gaps in the Middle East and North Africa? by  Fiuratti, Pennings and Torres 2024**
*Figure7.do is a Stata Do File that generates figure 7 of the paper.


***********************************************************************
* Working-age population in each skill group
***********************************************************************
import delimited "$path/RawData/WorkingAgePop_SEX_AGE_EDU_NB_A-2023-05-15.csv", clear

rename ref_area country

replace country = "Cote d'Ivoire" if country == "CÃ´te d'Ivoire"
replace country = "Egypt, Arab Rep." if country == "Egypt"
replace country = "Gambia, The" if country == "Gambia"
replace country = "Iran, Islamic Rep." if country == "Iran, Islamic Republic of"
replace country = "Korea, Rep." if country == "Korea, Republic of"
replace country = "Moldova" if country == "Moldova, Republic of"
replace country = "Vietnam" if country == "Viet Nam"
replace country = "Hong Kong SAR, China" if country == "Hong Kong, China"
replace country = "Lao PDR" if country == "Lao People's Democratic Republic"
replace country = "Venezuela, RB" if country == "Venezuela, Bolivarian Republic of"
replace country = "Türkiye" if country == "Turkey"
replace country = "Slovak Republic" if country == "Slovakia"
replace country = "Turkey" if country == "TÃ?rkiye"
replace country = "West Bank and Gaza" if country == "Occupied Palestinian Territory"
replace country = "Czech Republic" if country == "Czechia"
replace country = "Yemen, Rep." if country == "Yemen"

joinby country using "$path/RawData/list_regions", unmatched(both)
keep if _merge == 1 | _merge == 3
drop _merge

keep if classif1label == "Age (Youth, adults): 15-64" // As in Pennings 2022
drop if sexlabel == "Sex: Total" // drop totals
keep if strpos(classif2label, "Education (Aggregate levels):")

rename time year
rename obs_value population
drop classif1label obs_statuslabel note_*
drop indicatorlabel sourcelabel

split sexlabel, p(:)
rename sexlabel2 sex
drop sexlabel*
drop if strpos(sex, "Other")
replace sex = trim(sex)

split classif2label, p(:)
rename classif2label2 schooling
drop classif2label*

drop income region_long lending other
order country iso region year sex schooling

drop if strpos(schooling, "Total") // drop totals

replace schooling = "0" if strpos(schooling, "Advanced") == 0

collapse (sum) population, by(country iso region year sex schooling)
replace schooling = trim(schooling)

bysort country year sex: egen denom = total(population)

gen share = population/denom
drop denom

replace schooling = "1" if schooling != "0"

reshape wide population share, i(country iso region year sex) j(schooling) string

save "$path/StataData/EmploymentRates-ILO", replace


***********************************************************************
* Number of employed workers in each skill group
***********************************************************************
import delimited "$path/RawData/Employment_SEX_AGE_EDU_NB_A-2023-05-15.csv", clear

rename ref_area country

replace country = "Cote d'Ivoire" if country == "CÃ´te d'Ivoire"
replace country = "Egypt, Arab Rep." if country == "Egypt"
replace country = "Gambia, The" if country == "Gambia"
replace country = "Iran, Islamic Rep." if country == "Iran, Islamic Republic of"
replace country = "Korea, Rep." if country == "Korea, Republic of"
replace country = "Moldova" if country == "Moldova, Republic of"
replace country = "Vietnam" if country == "Viet Nam"
replace country = "Hong Kong SAR, China" if country == "Hong Kong, China"
replace country = "Lao PDR" if country == "Lao People's Democratic Republic"
replace country = "Venezuela, RB" if country == "Venezuela, Bolivarian Republic of"
replace country = "Türkiye" if country == "Turkey"
replace country = "Slovak Republic" if country == "Slovakia"
replace country = "Turkey" if country == "TÃ?rkiye"
replace country = "West Bank and Gaza" if country == "Occupied Palestinian Territory"
replace country = "Czech Republic" if country == "Czechia"
replace country = "Yemen, Rep." if country == "Yemen"

joinby country using "$path/RawData/list_regions", unmatched(both)
keep if _merge == 1 | _merge == 3
drop _merge

*keep if classif1label == "Age (Aggregate bands): 25-54" // prime-age workers
keep if classif1label == "Age (Youth, adults): 15-64" // As in Pennings 2022
drop if sexlabel == "Sex: Total" // drop totals
keep if strpos(classif2label, "Education (Aggregate levels):")

rename time year
rename obs_value employment
drop classif1label obs_statuslabel note_*
drop indicatorlabel sourcelabel

split sexlabel, p(:)
rename sexlabel2 sex
drop sexlabel*
drop if strpos(sex, "Other")
replace sex = trim(sex)

split classif2label, p(:)
rename classif2label2 schooling
drop classif2label*

drop income region_long lending other
order country iso region year sex schooling

drop if strpos(schooling, "Total") // drop totals

replace schooling = "0" if strpos(schooling, "Advanced") == 0

collapse (sum) employment, by(country iso region year sex schooling)
replace schooling = trim(schooling)

replace schooling = "1" if schooling != "0"

reshape wide employment, i(country iso region year sex) j(schooling) string

joinby country iso year sex using "$path/StataData/EmploymentRates-ILO", unmatched(both)
drop _merge
gen ratio0 = employment0/population0 
gen ratio1 = employment1/population1 // employment rate for those with advanced education

save "$path/StataData/EmploymentRates-ILO", replace

*******************
*Building Figure 7*
*******************

use "$path/StataData/EmploymentRates-ILO", clear
* ratio1 for US among women: .7832524
 
keep if ///
(country == "Algeria" & year ==	2017 ) | ///
(country == "Egypt, Arab Rep." & year ==	2017 ) | ///
(country == "Iran, Islamic Rep." & year ==	2018 ) | ///
(country == "Qatar" & year ==	2017 ) | ///
(country == "Tunisia" & year ==	2015 ) | ///
(country == "United Arab Emirates" & year ==	2018 ) | ///
(country == "West Bank and Gaza" & year ==	2018 ) | ///
(country == "Yemen, Rep." & year ==	2014 )

keep country iso year sex ratio* share* employment* population*

gen emp_pop_0= employment0/population0
gen emp_pop_1= employment1/population1

replace sex="M" if sex=="Male"
replace sex="F" if sex=="Female"

label var emp_pop_0 "Employed unskilled over Total unskilled"
label var emp_pop_1 "Employed skilled over Total skilled"

keep iso sex emp_pop_0 emp_pop_1

gen s=1 if sex=="M"
replace s=0 if sex=="F"

drop sex

reshape wide emp_pop_0 emp_pop_1, i(iso) j(s)

rename emp_pop_00 emp_pop_F0
rename emp_pop_10 emp_pop_F1
rename emp_pop_01 emp_pop_M0
rename emp_pop_11 emp_pop_M1

reshape long emp_pop_F emp_pop_M, i(iso) j(skilled)

gen s="S" if skilled==1
replace s="U" if skilled==0

set scheme s2color // default scheme

graph bar emp_pop_F emp_pop_M, over(s) over(iso) asyvars ytitle("") title("Employment-to-Population Ratio (ER) by Skill and Gender") graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white)) blabel(total, format(%9.2f) size(vsmall)) legend(order(1 2) label(1 "Female") label(2 "Male")) note("Note: U=Unskilled (not college educated) and S=Skilled (college educated)." "Plots the employment-to-population ratio for four groups, skilled-women, skilled-men, unskilled-women," "unskilled men (all of working age). For example ER(s,i)=skilled employed(i)/skilled pop(i);  where i=M,F")
graph export "$path/Figures/Figure7.pdf", replace as(pdf)
